@@ -1,11 +1,7 @@
-import Distribution.PackageDescription (
-  package,
-  packageDescription,
-  PackageIdentifier,
-  pkgVersion
-  )
+import Distribution.PackageDescription (package, packageDescription)
 import Distribution.PackageDescription.Parsec (readGenericPackageDescription)
 import Distribution.Pretty (prettyShow)
+import Distribution.Types.PackageId (PackageIdentifier, pkgVersion)
 import Distribution.Verbosity (silent)
 import System.Environment (getArgs)
 
